@@ -15,16 +15,22 @@ class Pop;
 class Image : public TshWgt
 {
 private:
-  bool       M;     // Mode: true.root window false.canvas
-  GtkWidget* W[3];  // 0.FullScreen 1.Image 2.Drawing_Area
-  GdkImlibImage* I; // Imlib Image
-  static GdkPixmap* P;     // Pixmap
-  GdkBitmap* B;     // Mask
-  Pop*       Pm;    // Pop Menu
-  int X,Y;          // X.Width, Y.Height
+  bool       M;        // Mode: true.root window false.canvas
+  GtkWidget* W[4];     // 0.FullScreen 1.Image 2.Drawing_Area 3.Pen Select
+  GdkImlibImage* I;    // Imlib Image
+  static GdkPixmap* P; // Pixmap
+  GdkBitmap* B;        // Mask
+  Pop*       Pm;       // Pop Menu
+  int X,Y;             // X.Width, Y.Height
   void setXY();
   void init();
 
+  static GdkGC* G;         // for draw()
+  static GdkRectangle R;   // for draw()
+  static GdkWindow* Gw;    // for draw()
+  static char* C[8];       // Color Strings
+  static GdkCursor* Cr[8]; // at draw()
+
 public:
   Image();
   ~Image();
@@ -38,10 +44,17 @@ public:
   void setMode(bool);
   void hideRoot();
   static void press(GtkWidget*, GdkEventButton*, Image*);
+  static void press2(GtkWidget*, GdkEventButton*, Image*);
   static void motion(GtkWidget*, GdkEventMotion*, Image*);
   static gint expose(GtkWidget*, GdkEventExpose*, Image*);
   static void draw(GtkWidget*, gdouble, gdouble);
   void popUp(GdkEventButton*);
   void newPop();
+
+  void pen(GdkEventButton*);
+  void penMenu();
+  static void setPenPoint(int, int);
+  void setPenWidth(int);
+  static void popFunc(GtkWidget*, char*);
 };
 #endif
