@@ -15,7 +15,7 @@ class Util : public TshObj
 {
 public:
   Util();
-  static char*  path(GtkCTreeNode*, char*, int, int);
+  static char*  path(GtkCTreeNode*, char*, char*, int, int);
   static char*  editCmd(char*, GList*);
   static bool   treeList(RowData*, int, GList*);
   static int    exe(RowData*, int);
